import axios from 'axios'
import { Toast } from 'vant'
import store from '@/store'
import router from '@/router'
import { getAPI } from '@/utils'

// create an axios instance
const instance = axios.create({
  baseURL: getAPI(),
  timeout: 5000,
  withCredentials: false,
})

// 设置post请求头
// instance.defaults.headers.post['Content-Type'] = 'application/x-www-form-urlencoded;charset=UTF-8'

// 请求拦截器
instance.interceptors.request.use((request) => {
  store.state.userInfo.userToken && (request.headers.userToken = store.state.userInfo.userToken)
  return request
})

// 响应拦截器
instance.interceptors.response.use(
  (response) => {
    const res = response.data || {}
    if (Number(res.code) === 200) {
      return Promise.resolve(res)
    } else {
      errorResultMessage(res)
      return Promise.reject(res)
    }
  },
  (error) => {
    console.error(error)
    const { response } = error || {}
    if (response) {
      errorHttpMessage(response)
    } else {
      Toast({
        message: '当前网络不可用，请检查你的网络设置', // 网络出错
        duration: 5 * 1000,
      })
    }

    return Promise.reject(error)
  },
)

/**
 * 业务错误
 */
function errorResultMessage(res) {
  const { code, msg } = res
  if (Number(code) === 401) {
    Toast.clear()
    store.commit('logout')
    toLogin()
  } else {
    Toast({
      message: msg || 'Error',
    })
  }
}

/**
 * HTTP错误
 */
function errorHttpMessage(res) {
  const { status } = res
  let message = ''

  if (status) {
    switch (Number(status)) {
      case 403:
        message = `${status} 网络请求被拒绝`
        break
      case 404:
        message = `${status} 网络请求不存在`
        break
      case 500:
        message = `${status} 服务器内部错误`
        break
    }
  }

  Toast({
    message,
    duration: 5 * 1000,
  })
}

/**
 * 跳转登录页面
 */
function toLogin() {
  console.log('跳转登录页')
  router.replace('/login')
}
export default instance
