// 数据校验函数

/**
 * 验证 - 是否有值
 * @param {*} value
 */
export function isDef(value) {
  return value !== undefined && value !== null
}

/**
 * 验证 - 是否是对象
 * @param {*} x
 */
export function isObj(x) {
  const type = typeof x
  return x !== null && (type === 'object' || type === 'function')
}

/**
 * 验证 - 是否是字符串
 * @param {string} str
 */
export function isString(str) {
  if (typeof str === 'string' || str instanceof String) {
    return true
  }
  return false
}

/**
 * 验证 - 是否是数字
 * @param {Number} value
 */
export function isNumber(value) {
  return /^\d+$/.test(value)
}

/**
 * 验证 - 是否是数组
 * @param {Array} arg
 */
export function isArray(arg) {
  if (typeof Array.isArray === 'undefined') {
    return Object.prototype.toString.call(arg) === '[object Array]'
  }
  return Array.isArray(arg)
}

/**
 * 验证 - 是否是对象{},非数组情况
 * @param {Array} arg
 */
export function isObject(arg) {
  return Object.prototype.toString.call(arg) === '[object Object]'
}

/**
 * 验证 - 是否为空数据
 * @param {*} obj
 */
export function isEmpty(obj) {
  if (obj === null || obj === undefined) {
    return true
  }
  if (isArray(obj)) {
    return obj.length === 0
  }
  if (isString(obj)) {
    return !`${obj}`.trim().length
  }
  if (JSON.stringify(obj) === '{}') {
    return true
  }
  return false
}
/**
 * 验证 - 是否是本地资源路径
 * @param {String} src
 */
export function isSrc(src) {
  const reg = /^(https?:)?\/\/.+$/i
  if (reg.test(src)) {
    return false
  } else {
    return true
  }
}

/**
 * 验证 - 是否是手机号
 * @param {String} val
 */
export function isPhone(value) {
  const reg = /^1[0-9]{10}$/
  return reg.test(value)
}
/**
 * 验证 - 是否是邮箱
 * @param {String} val
 */
export function isEmail(email) {
  const reg = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/
  return reg.test(email)
}
/**
 * 验证 - 手机验证码
 * @param {String} value
 * @description 6位纯数字组合
 */
export function isVcode(value) {
  const reg = /^[0-9]{6}$/
  return reg.test(value)
}

/**
 * 验证 - 图形验证码
 * @param {String} value
 * @description 4位大小写字母、数字组合
 */
export function isCaptchaCode(value) {
  const reg = /^[0-9A-Za-z]{4}$/
  return reg.test(value)
}

/**
 * 验证 - 用户名
 * @param {String} value
 * @description 1到32位的数字、字母、下划线组合，不能以下划线、横线开头
 */
export function isUsername(value) {
  const reg = /^(?!_)(?!-)\w{1,31}[a-zA-Z0-9]$/
  return reg.test(value)
}

/**
 * 验证 - 账户密码
 * @param {String} value
 * @description 8-25位大小写字母、数字或数字加字母的形式
 */
export function isPassword(value) {
  const reg = /^(?![0-9]+$)(?![a-zA-Z]+$)[0-9A-Za-z]{8,25}$/
  return reg.test(value)
}

/**
 * 验证 - 数据是否一致
 * @param {String} value1
 * @param {String} value2
 */
export function isSame(value1, value2) {
  return Object.is(value1, value2)
}
